/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/
package kieker.webgui.converter;

import java.util.HashMap;
import java.util.Map;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.convert.FacesConverter;

/**
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
@FacesConverter(value = ClassToStringConverter.NAME)
public class ClassToStringConverter implements Converter {

	/**
	 * The name of this class used by the xhtml-files.
	 */
	public static final String NAME = "kieker.webgui.converter.ClassToStringConverter";

	/**
	 * This field stores the mapping between the classes as string and the actual classes.
	 */
	private final Map<String, Class<?>> mapping;

	/**
	 * Creates a new instance of this class.
	 */
	public ClassToStringConverter() {
		this.mapping = new HashMap<String, Class<?>>();
	}

	@Override
	public Object getAsObject(final FacesContext fc, final UIComponent uic, final String string) {
		return this.mapping.get(string);
	}

	@Override
	public String getAsString(final FacesContext fc, final UIComponent uic, final Object o) {
		final String result = ((Class<?>) o).getName();
		this.mapping.put(result, (Class<?>) o);
		return result;
	}
}
